"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.UsbDeviceDev = exports.EvamUsbManagerDev = void 0;
class EvamUsbManagerDev {
    constructor(usb) {
        this.usb = usb;
    }
    mapUSBDeviceToUsbDevice(dev) {
        return new UsbDeviceDev(this.usb, dev, dev.serialNumber, dev.productId, dev.productName, dev.vendorId, `${dev.usbVersionMajor}.${dev.usbVersionMinor}.${dev.usbVersionSubminor}`, dev.deviceClass, dev.deviceSubclass, dev.deviceProtocol);
    }
    async getDeviceList() {
        let devices = await this.usb.getDevices();
        return devices.map((dev) => this.mapUSBDeviceToUsbDevice(dev));
    }
    async hasPermission(device) {
        let devices = await this.getDeviceList();
        return devices.filter((dev) => {
            return dev.vendorId === device.vendorId
                && dev.productName === device.productName
                && dev.productId === device.productId
                && dev.serialNumber === device.serialNumber;
        }).length > 0;
    }
    async openDevice(device) {
        await device.open();
    }
    async requestPermission(filters, callback) {
        this.usb.requestDevice({
            filters: filters
        }).then((dev) => {
            callback(this.mapUSBDeviceToUsbDevice(dev), "Success");
        }).catch((err) => {
            callback(undefined, `Error: ${err}`);
        });
    }
}
exports.EvamUsbManagerDev = EvamUsbManagerDev;
class UsbDeviceDev {
    constructor(usb, dev, serialNumber, productId, productName, vendorId, version, classCode, subclassCode, protocolCode) {
        this.serialNumber = serialNumber;
        this.productId = productId;
        this.productName = productName;
        this.vendorId = vendorId;
        this.version = version;
        this.classCode = classCode;
        this.subclassCode = subclassCode;
        this.protocolCode = protocolCode;
        this.usb = usb;
        this.dev = dev;
    }
    mapUSBTransferInResultToUsbTransferResult(result) {
        var _a, _b;
        let data = [];
        console.log(`Offset: ${(_a = result.data) === null || _a === void 0 ? void 0 : _a.byteOffset}, Length: ${(_b = result.data) === null || _b === void 0 ? void 0 : _b.byteLength}`);
        if (result.data !== undefined) {
            for (let i = result.data.byteOffset; i < result.data.byteLength; i++) {
                data.push(result.data.getInt8(i));
            }
        }
        return { data: data, status: result.status || "Unknown", length: data.length };
    }
    mapUSBInterfaceToUsbInterface(inf) {
        return {
            interfaceNumber: inf.interfaceNumber,
            endpoints: inf.alternate.endpoints
        };
    }
    async claimInterface(interfaceNumber, force) {
        await this.dev.claimInterface(interfaceNumber);
    }
    async close() {
        await this.dev.close();
    }
    async controlTransferIn(requestType, recipient, request, value, index, length, timeout) {
        let result = await this.dev.controlTransferIn({
            requestType: requestType,
            recipient: recipient,
            request: request,
            value: value,
            index: index
        }, length);
        return this.mapUSBTransferInResultToUsbTransferResult(result);
    }
    async controlTransferOut(requestType, recipient, request, value, index, data, timeout) {
        let result = await this.dev.controlTransferOut({
            requestType: requestType,
            recipient: recipient,
            request: request,
            value: value,
            index: index
        }, data);
        let out = this.mapUSBTransferInResultToUsbTransferResult(result);
        out.length = result.bytesWritten;
        return out;
    }
    async forget() {
        await this.dev.forget();
    }
    getInterfaces() {
        var _a;
        let interfaces = ((_a = this.dev.configuration) === null || _a === void 0 ? void 0 : _a.interfaces) || [];
        return interfaces.map((inf) => this.mapUSBInterfaceToUsbInterface(inf));
    }
    async releaseInterface(interfaceNumber) {
        await this.dev.releaseInterface(interfaceNumber);
    }
    async transferIn(endpointNumber, length, timeout) {
        let result = await this.dev.transferIn(endpointNumber, length);
        return this.mapUSBTransferInResultToUsbTransferResult(result);
    }
    async transferOut(endpointNumber, data, timeout) {
        let result = await this.dev.transferOut(endpointNumber, data);
        let out = this.mapUSBTransferInResultToUsbTransferResult(result);
        out.length = result.bytesWritten;
        return out;
    }
    async open() {
        await this.dev.open();
    }
}
exports.UsbDeviceDev = UsbDeviceDev;
//# sourceMappingURL=EvamUsbManagerDev.js.map